# frozen_string_literal: true
require 'horn_of_plenty/adapters/github/error'
require 'rspeckled/spec_helpers/rspeckled'

module    HornOfPlenty
module    Adapters
module    Github
describe  Error do
  it 'can understand when there is a bad request' do
    error = Error.lookup(400, 'This is the error message.')

    expect(error).to         be_an Errors::BadRequest
    expect(error.message).to eql "There was a general issue with your request.\n" \
                                 "This is the error message."
  end

  it 'can understand when there is an authentication failure' do
    error = Error.lookup(401, 'This is the error message.')

    expect(error).to         be_an Errors::AuthenticationFailure
    expect(error.message).to eql "There was a problem with the credentials you " \
                                 "provided.\nThis is the error message."
  end

  it 'can understand when there is a server error' do
    error = Error.lookup(500, 'This is the error message.')

    expect(error).to         be_an Errors::ServerError
    expect(error.message).to eql "Something went wrong on the server.\n" \
                                 "This is the error message."
  end
end
end
end
end
