# frozen_string_literal: true
require 'json'
require 'horn_of_plenty/adapters/github/parsers/board'
require 'rspeckled/spec_helpers/rspeckled'

module    HornOfPlenty
module    Adapters
module    Github
module    Parsers
describe  Board do
  let(:board_json_response_path)   { 'spec/fixtures/responses/board_github.json' }
  let(:board_json_response_file)   { Pathname.pwd.join(board_json_response_path) }
  let(:board_json_response_string) { board_json_response_file.read }
  let(:board_json)                 { JSON.load(board_json_response_string) }

  it 'can convert a Github JSON board response to a Board' do
    board = Board.to_model(board_json)

    # rubocop:disable Metrics/LineLength
    expect(board).to                                       be_a HornOfPlenty::Models::Board
    expect(board.id).to                                    eql '1'
    expect(board.author_id).to                             eql 'jfelchner'
    expect(board.title).to                                 eql 'Main'
    expect(board.description).to                           eql 'Hello'
    expect(board.created_at).to                            eql Time.utc(2016, 10, 13, 2, 49, 33)
    expect(board.updated_at).to                            eql Time.utc(2016, 10, 13, 2, 51, 10)
    # rubocop:enable Metrics/LineLength
  end

  it 'has access to all of the methods needed to generate the hash' do
    board = Board.to_model(board_json)

    expect { board.to_h }.not_to raise_error
  end
end
end
end
end
end
