# frozen_string_literal: true
require 'json'
require 'horn_of_plenty/adapters/github/parsers/card'
require 'rspeckled/spec_helpers/rspeckled'

module    HornOfPlenty
module    Adapters
module    Github
module    Parsers
describe  Card do
  let(:card_json_response_path)   { 'spec/fixtures/responses/card_github.json' }
  let(:card_json_response_file)   { Pathname.pwd.join(card_json_response_path) }
  let(:card_json_response_string) { card_json_response_file.read }
  let(:card_json)                 { JSON.load(card_json_response_string) }

  it 'can convert a Github JSON card response to a Card' do
    card = Card.to_model(card_json)

    expect(card).to                           be_a HornOfPlenty::Models::Card
    expect(card.id).to                        eql '1478'
    expect(card.lane_id).to                   eql '366'
    expect(card.status).to                    eql nil
    expect(card.repository).to                eql 'api-playground/projects-test'
    expect(card.content_type).to              eql 'Note'
    expect(card.content_id).to                eql nil
    expect(card.title).to                     eql 'Add payload for delete Project column'
    expect(card.description).to               eql "This is the description\nAnd more."
    expect(card.labels).to                    eql []
    expect(card.created_at).to                eql Time.utc(2016, 9, 5, 14, 21, 6)
    expect(card.updated_at).to                eql Time.utc(2016, 9, 5, 14, 20, 22)
  end

  it 'can convert a Github JSON card response to a Card if the card content is an ' \
     'issue' do

    card_json['note']        = nil
    card_json['content_url'] = 'https://api.github.com/repos/api-playground/projects-test/issues/3'

    card = Card.to_model(card_json)

    expect(card).to                           be_a HornOfPlenty::Models::Card
    expect(card.id).to                        eql '1478'
    expect(card.lane_id).to                   eql '366'
    expect(card.status).to                    eql nil
    expect(card.repository).to                eql 'api-playground/projects-test'
    expect(card.content_type).to              eql 'Issue'
    expect(card.content_id).to                eql '3'
    expect(card.title).to                     eql nil
    expect(card.description).to               eql nil
    expect(card.labels).to                    eql []
    expect(card.created_at).to                eql Time.utc(2016, 9, 5, 14, 21, 6)
    expect(card.updated_at).to                eql Time.utc(2016, 9, 5, 14, 20, 22)
  end

  it 'has access to all of the methods needed to generate the hash' do
    card = Card.to_model(card_json)

    expect { card.to_h }.not_to raise_error
  end
end
end
end
end
end
