# frozen_string_literal: true
require 'json'
require 'horn_of_plenty/adapters/github/parsers/issue'
require 'rspeckled/spec_helpers/rspeckled'

module    HornOfPlenty
module    Adapters
module    Github
module    Parsers
describe  Issue do
  let(:issue_json_response_path)   { 'spec/fixtures/responses/issue_github.json' }
  let(:issue_json_response_file)   { Pathname.pwd.join(issue_json_response_path) }
  let(:issue_json_response_string) { issue_json_response_file.read }
  let(:issue_json)                 { JSON.load(issue_json_response_string) }

  it 'can convert a Github JSON issue response to a Issue' do
    issue = Issue.to_model(issue_json)

    # rubocop:disable Metrics/LineLength
    expect(issue).to                                       be_a HornOfPlenty::Models::Issue
    expect(issue.id).to                                    eql '1347'
    expect(issue.author_id).to                             eql 'octocat'
    expect(issue.assignee_ids).to                          eql %w{mswezey jfelchner}
    expect(issue.closer_id).to                             eql 'mswezey'
    expect(issue.repository).to                            eql 'octocat/Hello-World'
    expect(issue.status).to                                eql 'open'
    expect(issue.title).to                                 eql 'Found a bug'
    expect(issue.description).to                           eql "I'm having a problem with this."
    expect(issue.labels).to                                eql %w{bug v1.0}
    expect(issue.closed_at).to                             eql Time.utc(2013,  2, 12, 13, 22,  1)
    expect(issue.created_at).to                            eql Time.utc(2011,  4, 22, 13, 33, 45)
    expect(issue.updated_at).to                            eql Time.utc(2011,  4, 22, 13, 33, 48)

    expect(issue).to                                       have_pull_request
    # rubocop:enable Metrics/LineLength
  end

  it 'has access to all of the methods needed to generate the hash' do
    issue = Issue.to_model(issue_json)

    expect { issue.to_h }.not_to raise_error
  end
end
end
end
end
end
