# frozen_string_literal: true
require 'json'
require 'horn_of_plenty/adapters/github/parsers/lane'
require 'rspeckled/spec_helpers/rspeckled'

module    HornOfPlenty
module    Adapters
module    Github
module    Parsers
describe  Lane do
  let(:lane_json_response_path)   { 'spec/fixtures/responses/lane_github.json' }
  let(:lane_json_response_file)   { Pathname.pwd.join(lane_json_response_path) }
  let(:lane_json_response_string) { lane_json_response_file.read }
  let(:lane_json)                 { JSON.load(lane_json_response_string) }

  it 'can convert a Github JSON lane response to a Lane' do
    lane = Lane.to_model(lane_json)

    # rubocop:disable Metrics/LineLength
    expect(lane).to                                       be_a HornOfPlenty::Models::Lane
    expect(lane.id).to                                    eql '365'
    expect(lane.board_id).to                              eql '2'
    expect(lane.title).to                                 eql 'To Do'
    expect(lane.created_at).to                            eql Time.utc(2016, 9, 5, 14, 18, 44)
    expect(lane.updated_at).to                            eql Time.utc(2016, 9, 5, 14, 22, 28)
    # rubocop:enable Metrics/LineLength
  end

  it 'has access to all of the methods needed to generate the hash' do
    lane = Lane.to_model(lane_json)

    expect { lane.to_h }.not_to raise_error
  end
end
end
end
end
end
