# frozen_string_literal: true
require 'json'
require 'horn_of_plenty/adapters/github/parsers/pull_request'
require 'rspeckled/spec_helpers/rspeckled'

module    HornOfPlenty
module    Adapters
module    Github
module    Parsers
describe  PullRequest do
  # rubocop:disable Metrics/LineLength
  let(:pull_request_json_response_path)   { 'spec/fixtures/responses/pull_request_github.json' }
  let(:pull_request_json_response_file)   { Pathname.pwd.join(pull_request_json_response_path) }
  let(:pull_request_json_response_string) { pull_request_json_response_file.read }
  let(:pull_request_json)                 { JSON.load(pull_request_json_response_string) }
  # rubocop:enable Metrics/LineLength

  it 'can convert a Github JSON pull request response to a PullRequest' do
    pull_request = PullRequest.to_model(pull_request_json)

    # rubocop:disable Metrics/LineLength
    expect(pull_request).to                   be_a HornOfPlenty::Models::PullRequest
    expect(pull_request.id).to                eql '6'
    expect(pull_request.author_id).to         eql 'markmakes'
    expect(pull_request.assignee_ids).to      eql %w{jfelchner}
    expect(pull_request.closer_id).to         eql nil
    expect(pull_request.merger_id).to         eql 'mswezey'
    expect(pull_request.repository).to        eql 'RealSavvy/realsavvy'
    expect(pull_request.status).to            eql 'merged'
    expect(pull_request.title).to             eql 'GLUX updates!'
    expect(pull_request.description).to       eql "Footer is designed, but some of the items are placeholders till functionality is written.\n\nOtherwise loads of CSS edits for responsiveness, design, and colors."
    expect(pull_request.labels).to            eql []
    expect(pull_request.closed_at).to         eql Time.utc(2016,  5, 10, 20, 11, 54)
    expect(pull_request.created_at).to        eql Time.utc(2016,  5, 10,  4, 52, 19)
    expect(pull_request.updated_at).to        eql Time.utc(2016,  5, 10, 20, 11, 55)

    expect(pull_request).not_to               have_pull_request
    # rubocop:enable Metrics/LineLength
  end

  it 'has access to all of the methods needed to generate the hash' do
    pull_request = PullRequest.to_model(pull_request_json)

    expect { pull_request.to_h }.not_to raise_error
  end
end
end
end
end
end
