# frozen_string_literal: true
require 'chamber'
require 'horn_of_plenty/adapters/github/repositories/card'
require 'rspeckled/spec_helpers/rspeckled'

module    HornOfPlenty
module    Adapters
module    Github
module    Repositories
describe  Card do
  before(:each) { Adapters::Github.config.token = Chamber.env.adapters.github.token }

  it 'can retrieve cards for a lane' do
    cards = Card.fetch(repository: 'thekompanee/hustle-and-flow-issue-dump',
                       query:      {
                         lane_id: '215863',
                       })

    expect(cards.length).to eql 4
  end

  it 'can retrieve a note card' do
    cards = Card.fetch(repository: 'thekompanee/hustle-and-flow-issue-dump',
                       query:      {
                         id: '451033',
                       })

    card = cards.first

    expect(card.content_type).to eql 'Note'
    expect(card.title).to        eql 'First Card'
  end

  it 'can retrieve an issue card' do
    cards = Card.fetch(repository: 'thekompanee/hustle-and-flow-issue-dump',
                       query:      {
                         id: '473148',
                       })

    card = cards.first

    expect(card.content_type).to eql 'Issue'
    expect(card.content_id).to   eql '2'
    expect(card.title).to        eql 'Second Card'
    expect(card.description).to  eql 'Here is some text for the Hello issue'
    expect(card.labels).to       eql %w{invalid}
  end

  it 'can retrieve a pull request card' do
    cards = Card.fetch(repository: 'thekompanee/hustle-and-flow-issue-dump',
                       query:      {
                         id: '475442',
                       })

    card = cards.first

    expect(card.content_type).to eql 'PullRequest'
    expect(card.content_id).to   eql '3'
    expect(card.title).to        eql 'My Bar Pull Request'
    expect(card.description).to  eql "Here's my PR description"
    expect(card.labels).to       eql %w{duplicate}
  end
end
end
end
end
end
