# frozen_string_literal: true
require 'rspeckled/spec_helpers/rspeckled'
require 'horn_of_plenty/adapters/github/requests/list_boards'

module    HornOfPlenty
module    Adapters
module    Github
module    Requests
describe  ListBoards do
  it 'has the correct method' do
    request = ListBoards.new(query: 'what', repository: 'yeah')

    expect(request.method).to eql 'get'
  end

  it 'has the correct path based on the repository name' do
    request = ListBoards.new(query: {}, repository: 'yeah')

    expect(request.path).to eql 'repos/yeah/projects'
  end

  it 'has the correct path based on the ID' do
    request = ListBoards.new(repository: 'yeah', query: { id: '1' })

    expect(request.path).to eql 'repos/yeah/projects/1'
  end

  it 'properly combines the query and pagination hashes' do
    query_hash      = { 'some_var' => 'some_val', 'other_var' => 'other_val' }
    pagination_hash = { 'some_var' => 'boom' }

    request = ListBoards.new(query:      query_hash,
                             pagination: pagination_hash,
                             repository: 'yeah')

    expect(request.to_h).to eql('some_var' => 'boom', 'other_var' => 'other_val')
  end
end
end
end
end
end
