# frozen_string_literal: true
require 'rspeckled/spec_helpers/rspeckled'
require 'horn_of_plenty/adapters/github/requests/list_cards'

module    HornOfPlenty
module    Adapters
module    Github
module    Requests
describe  ListCards do
  it 'has the correct method' do
    request = ListCards.new(query: 'what', repository: 'yeah')

    expect(request.method).to eql 'get'
  end

  it 'has the correct path based on the repository name' do
    request = ListCards.new(repository: 'yeah',
                            query:      { lane_id: '1' })

    expect(request.path).to eql 'repos/yeah/projects/columns/1/cards'
  end

  it 'has the correct path based on the column ID' do
    request = ListCards.new(repository: 'yeah',
                            query:      { lane_id: '1' })

    expect(request.path).to eql 'repos/yeah/projects/columns/1/cards'
  end

  it 'has the correct path based on the project ID and column ID' do
    request = ListCards.new(repository: 'yeah',
                            query:      { id: '2', lane_id: '1' })

    expect(request.path).to eql 'repos/yeah/projects/columns/cards/2'
  end

  it 'properly combines the query and pagination hashes' do
    query_hash      = { 'some_var' => 'some_val', 'other_var' => 'other_val' }
    pagination_hash = { 'some_var' => 'boom' }

    request = ListCards.new(query:      query_hash,
                            pagination: pagination_hash,
                            repository: 'yeah')

    expect(request.to_h).to eql('some_var' => 'boom', 'other_var' => 'other_val')
  end
end
end
end
end
end
