# frozen_string_literal: true
require 'horn_of_plenty/models/board'
require 'horn_of_plenty/adapters/github/client'
require 'horn_of_plenty/adapters/github/responses/list_boards'
require 'horn_of_plenty/adapters/github/requests/list_boards'
require 'chamber'
require 'rspeckled/spec_helpers/rspeckled'

module    HornOfPlenty
module    Adapters
module    Github
module    Responses
describe  ListBoards do
  it 'can retrieve boards' do
    client        = Client.new(url:     'https://api.github.com',
                               version: 'inertia-preview',
                               token:   Chamber.env.adapters.github.token,
                               logger:  $stdout)
    board_request = Requests::ListBoards.new(
                      repository: 'thekompanee/hustle-and-flow-issue-dump',
    )

    board_response = client.request(board_request)

    expect(board_response.status_code).to eql 200
    expect(board_response.body.length).to eql 2
    expect(board_response).to             be_successful
    expect(board_response.body).to        include(
      a_hash_including(
        'name' => 'Main',
      ),
    )
  end

  it 'can handle if a board does not exist' do
    client        = Client.new(url:     'https://api.github.com',
                               version: 'inertia-preview',
                               token:   Chamber.env.adapters.github.token,
                               logger:  $stdout)
    board_request = Requests::ListBoards.new(repository: 'thekompanee/hustle_and_flow')

    board_response = client.request(board_request)

    expect(board_response.status_code).to eql 200
    expect(board_response.body).to        be_empty
    expect(board_response).to             be_successful
  end

  it 'can handle if there is an error' do
    client        = Client.new(url:     'https://api.github.com',
                               version: 'inertia-preview',
                               token:   Chamber.env.adapters.github.token,
                               logger:  $stdout)
    board_request = Requests::ListBoards.new(repository: 'thekompanee/no-repo-here')

    expect { client.request(board_request) }.to raise_error Github::Errors::NotFound
  end

  it 'can parse the boards that are returned' do
    client        = Client.new(url:     'https://api.github.com',
                               version: 'inertia-preview',
                               token:   Chamber.env.adapters.github.token,
                               logger:  $stdout)
    board_request = Requests::ListBoards.new(
                      repository: 'thekompanee/hustle-and-flow-issue-dump',
    )

    board_response = client.request(board_request)
    board          = board_response.result.first

    expect(board).to       be_a HornOfPlenty::Models::Board
    expect(board.title).to eql 'Main'
  end
end
end
end
end
end
