# frozen_string_literal: true
require 'horn_of_plenty/models/card'
require 'horn_of_plenty/adapters/github/client'
require 'horn_of_plenty/adapters/github/responses/list_cards'
require 'horn_of_plenty/adapters/github/requests/list_cards'
require 'chamber'
require 'rspeckled/spec_helpers/rspeckled'

module    HornOfPlenty
module    Adapters
module    Github
module    Responses
describe  ListCards do
  it 'can retrieve cards' do
    client       = Client.new(url:     'https://api.github.com',
                              version: 'inertia-preview',
                              token:   Chamber.env.adapters.github.token,
                              logger:  $stdout)
    card_request = Requests::ListCards.new(
                     repository: 'thekompanee/hustle-and-flow-issue-dump',
                     query:      { lane_id: 215_863 },
    )

    card_response = client.request(card_request)

    expect(card_response.status_code).to eql 200
    expect(card_response.body.length).to eql 4
    expect(card_response).to             be_successful
    expect(card_response.body).to        include(
      a_hash_including(
        'note' => 'First Card',
      ),
    )
  end

  it 'can handle if a lane does not have any cards' do
    client       = Client.new(url:     'https://api.github.com',
                              version: 'inertia-preview',
                              token:   Chamber.env.adapters.github.token,
                              logger:  $stdout)
    card_request = Requests::ListCards.new(
                     repository: 'thekompanee/hustle-and-flow-issue-dump',
                     query:      { lane_id: 215_866 },
    )

    card_response = client.request(card_request)

    expect(card_response.status_code).to eql 200
    expect(card_response.body).to        be_empty
    expect(card_response).to             be_successful
  end

  it 'can handle if there is an error' do
    client       = Client.new(url:     'https://api.github.com',
                              version: 'inertia-preview',
                              token:   Chamber.env.adapters.github.token,
                              logger:  $stdout)
    card_request = Requests::ListCards.new(
                     repository: 'thekompanee/no-repo-here',
                     query:      { lane_id: 3 },
    )

    expect { client.request(card_request) }.to raise_error Github::Errors::NotFound
  end

  it 'can parse notes that are returned' do
    client       = Client.new(url:     'https://api.github.com',
                              version: 'inertia-preview',
                              token:   Chamber.env.adapters.github.token,
                              logger:  $stdout)
    card_request = Requests::ListCards.new(
                     repository: 'thekompanee/hustle-and-flow-issue-dump',
                     query:      { lane_id: 215_863 },
    )

    card_response = client.request(card_request)
    card          = card_response.result.first

    expect(card).to       be_a HornOfPlenty::Models::Card
    expect(card.title).to eql 'First Card'
  end
end
end
end
end
end
