# frozen_string_literal: true
require 'horn_of_plenty/models/lane'
require 'horn_of_plenty/adapters/github/client'
require 'horn_of_plenty/adapters/github/responses/list_lanes'
require 'horn_of_plenty/adapters/github/requests/list_lanes'
require 'chamber'
require 'rspeckled/spec_helpers/rspeckled'

module    HornOfPlenty
module    Adapters
module    Github
module    Responses
describe  ListLanes do
  it 'can retrieve lanes' do
    client       = Client.new(url:     'https://api.github.com',
                              version: 'inertia-preview',
                              token:   Chamber.env.adapters.github.token,
                              logger:  $stdout)
    lane_request = Requests::ListLanes.new(
                     repository: 'thekompanee/hustle-and-flow-issue-dump',
                     query:      { board_id: 1 },
    )

    lane_response = client.request(lane_request)

    expect(lane_response.status_code).to eql 200
    expect(lane_response.body.length).to eql 9
    expect(lane_response).to             be_successful
    expect(lane_response.body).to        include(
      a_hash_including(
        'name' => 'Backlog',
      ),
    )
  end

  it 'can handle if a lane does not exist' do
    client       = Client.new(url:     'https://api.github.com',
                              version: 'inertia-preview',
                              token:   Chamber.env.adapters.github.token,
                              logger:  $stdout)
    lane_request = Requests::ListLanes.new(
                     repository: 'thekompanee/hustle-and-flow-issue-dump',
                     query:      { board_id: 3 },
    )

    lane_response = client.request(lane_request)

    expect(lane_response.status_code).to eql 200
    expect(lane_response.body).to        be_empty
    expect(lane_response).to             be_successful
  end

  it 'can handle if there is an error' do
    client       = Client.new(url:     'https://api.github.com',
                              version: 'inertia-preview',
                              token:   Chamber.env.adapters.github.token,
                              logger:  $stdout)
    lane_request = Requests::ListLanes.new(
                     repository: 'thekompanee/no-repo-here',
                     query:      { board_id: 3 },
    )

    expect { client.request(lane_request) }.to raise_error Github::Errors::NotFound
  end

  it 'can parse the lanes that are returned' do
    client       = Client.new(url:     'https://api.github.com',
                              version: 'inertia-preview',
                              token:   Chamber.env.adapters.github.token,
                              logger:  $stdout)
    lane_request = Requests::ListLanes.new(
                     repository: 'thekompanee/hustle-and-flow-issue-dump',
                     query:      { board_id: 1 },
    )

    lane_response = client.request(lane_request)
    lane          = lane_response.result.first

    expect(lane).to       be_a HornOfPlenty::Models::Lane
    expect(lane.title).to eql 'Wishlist'
  end
end
end
end
end
end
