# frozen_string_literal: true
require 'faraday'
require 'chamber'
require 'horn_of_plenty/adapters/github/configuration'
require 'horn_of_plenty/repositories/board'
require 'horn_of_plenty/models/board'
require 'rspeckled/spec_helpers/rspeckled'

module    HornOfPlenty
module    Repositories
describe  Board do
  before(:each) { Adapters::Github.config.token = Chamber.env.adapters.github.token }

  it 'can retrieve boards from an adapter' do
    boards = Board.fetch(adapter:    'github',
                         repository: 'thekompanee/hustle-and-flow-issue-dump')

    expect(boards.length).to eql 2
  end

  it 'can retrieve a board by ID' do
    boards = Board.fetch(
                           adapter:    'github',
                           repository: 'thekompanee/hustle-and-flow-issue-dump',
                           query:      {
                             id: 1,
                           },
    )

    expect(boards.first).to       be_a HornOfPlenty::Models::Board
    expect(boards.first.title).to eql 'Main'
  end

  it 'can handle if the board with the ID cannot be found' do
    boards = Board.fetch(
                           adapter:    'github',
                           repository: 'thekompanee/hustle-and-flow-issue-dump',
                           query:      {
                             id: 2,
                           },
    )

    expect { boards.first }.to raise_error \
      HornOfPlenty::Adapters::Github::Errors::NotFound
  end
end
end
end
