# frozen_string_literal: true
require 'faraday'
require 'chamber'
require 'horn_of_plenty/adapters/github/configuration'
require 'horn_of_plenty/repositories/card'
require 'horn_of_plenty/models/card'
require 'rspeckled/spec_helpers/rspeckled'

module    HornOfPlenty
module    Repositories
describe  Card do
  before(:each) { Adapters::Github.config.token = Chamber.env.adapters.github.token }

  it 'can retrieve cards from an adapter' do
    cards = Card.fetch(adapter:    'github',
                       repository: 'thekompanee/hustle-and-flow-issue-dump',
                       query:      {
                         lane_id: 215_863,
                       })

    expect(cards.length).to eql 4
  end

  it 'can retrieve a card by ID' do
    cards = Card.fetch(
                        adapter:    'github',
                        repository: 'thekompanee/hustle-and-flow-issue-dump',
                        query:      {
                          id: 451_033,
                        },
    )

    expect(cards.first).to       be_a HornOfPlenty::Models::Card
    expect(cards.first.title).to eql 'First Card'
  end

  it 'can handle if the card with the ID cannot be found' do
    cards = Card.fetch(
                        adapter:    'github',
                        repository: 'thekompanee/hustle-and-flow-issue-dump',
                        query:      {
                          id: 2,
                        },
    )

    expect { cards.first }.to raise_error \
      HornOfPlenty::Adapters::Github::Errors::NotFound
  end
end
end
end
