# frozen_string_literal: true
require 'faraday'
require 'chamber'
require 'horn_of_plenty/adapters/github/configuration'
require 'horn_of_plenty/repositories/issue'
require 'horn_of_plenty/models/issue'
require 'rspeckled/spec_helpers/rspeckled'

module    HornOfPlenty
module    Repositories
describe  Issue do
  before(:each) { Adapters::Github.config.token = Chamber.env.adapters.github.token }

  it 'can retrieve issues from an adapter' do
    issues = Issue.fetch(adapter:    'github',
                         repository: 'thekompanee/hustle-and-flow-issue-dump')

    expect(issues.length).to eql 3
  end

  it 'can retrieve a issue by ID' do
    issues = Issue.fetch(
                           adapter:    'github',
                           repository: 'thekompanee/hustle-and-flow-issue-dump',
                           query:      {
                             id: 1,
                           },
    )

    expect(issues.first).to       be_a HornOfPlenty::Models::Issue
    expect(issues.first.title).to eql 'Menu item specifications not working'
  end

  it 'can handle if the issue with the ID cannot be found' do
    issues = Issue.fetch(
                           adapter:    'github',
                           repository: 'thekompanee/hustle-and-flow-issue-dump',
                           query:      {
                             id: 100_000,
                           },
    )

    expect { issues.first }.to raise_error \
      HornOfPlenty::Adapters::Github::Errors::NotFound
  end
end
end
end
