# frozen_string_literal: true
require 'faraday'
require 'chamber'
require 'horn_of_plenty/adapters/github/configuration'
require 'horn_of_plenty/repositories/lane'
require 'horn_of_plenty/models/lane'
require 'rspeckled/spec_helpers/rspeckled'

module    HornOfPlenty
module    Repositories
describe  Lane do
  before(:each) { Adapters::Github.config.token = Chamber.env.adapters.github.token }

  it 'can retrieve lanes from an adapter' do
    lanes = Lane.fetch(adapter:    'github',
                       repository: 'thekompanee/hustle-and-flow-issue-dump',
                       query:      {
                         board_id: 1,
                       })

    expect(lanes.length).to eql 9
  end

  it 'can retrieve a lane by ID' do
    lanes = Lane.fetch(
                        adapter:    'github',
                        repository: 'thekompanee/hustle-and-flow-issue-dump',
                        query:      {
                          id: 215_863,
                        },
    )

    expect(lanes.first).to       be_a HornOfPlenty::Models::Lane
    expect(lanes.first.title).to eql 'Wishlist'
  end

  it 'can handle if the lane with the ID cannot be found' do
    lanes = Lane.fetch(
                        adapter:    'github',
                        repository: 'thekompanee/hustle-and-flow-issue-dump',
                        query:      {
                          id: 2,
                        },
    )

    expect { lanes.first }.to raise_error \
      HornOfPlenty::Adapters::Github::Errors::NotFound
  end
end
end
end
