# frozen_string_literal: true
require 'faraday'
require 'chamber'
require 'horn_of_plenty/adapters/github/configuration'
require 'horn_of_plenty/repositories/pull_request'
require 'horn_of_plenty/models/pull_request'
require 'rspeckled/spec_helpers/rspeckled'

module    HornOfPlenty
module    Repositories
describe  PullRequest do
  before(:each) { Adapters::Github.config.token = Chamber.env.adapters.github.token }

  it 'can retrieve pull requests' do
    pull_requests = PullRequest.fetch(
      adapter:    'github',
      repository: 'thekompanee/hustle-and-flow-issue-dump',
    )

    expect(pull_requests.length).to eql 1
  end

  it 'can retrieve a pull request by ID' do
    pull_requests = PullRequest.fetch(
      adapter:    'github',
      repository: 'thekompanee/hustle-and-flow-issue-dump',
      query:      {
        id: 3,
      },
    )

    expect(pull_requests.first).to       be_a HornOfPlenty::Models::PullRequest
    expect(pull_requests.first.title).to eql 'My Bar Pull Request'
  end

  it 'can handle if the pull request with the ID cannot be found' do
    pull_requests = PullRequest.fetch(
      adapter:    'github',
      repository: 'thekompanee/hustle-and-flow-issue-dump',
      query:      {
        id: 2,
      },
    )

    expect { pull_requests.first }.to raise_error \
      HornOfPlenty::Adapters::Github::Errors::NotFound
  end
end
end
end
